# tickcatcher
The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators.
All requests require authentication using your RapidAPI key.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.17.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/yagiziskirik/tickcatcher-sdk.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/yagiziskirik/tickcatcher-sdk.git`)

Then import the package:
```python
import tickcatcher
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import tickcatcher
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import tickcatcher
from tickcatcher.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://tickcatcher.p.rapidapi.com
# See configuration.py for a list of all supported configuration parameters.
configuration = tickcatcher.Configuration(
    host = "https://tickcatcher.p.rapidapi.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: rapidapiKey
configuration.api_key['rapidapiKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['rapidapiKey'] = 'Bearer'


# Enter a context with an instance of the API client
with tickcatcher.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = tickcatcher.CalendarApi(api_client)
    start_date = 1762194992000 # int | Javascript style epoch time with milliseconds (i.e. 1762194992000). (optional)
    end_date = 1762194992000 # int | Javascript style epoch time with milliseconds (i.e. 1762194992000). (optional)

    try:
        # Get economic calendar within a selected period
        api_response = api_instance.calendar(start_date=start_date, end_date=end_date)
        print("The response of CalendarApi->calendar:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CalendarApi->calendar: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://tickcatcher.p.rapidapi.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CalendarApi* | [**calendar**](docs/CalendarApi.md#calendar) | **GET** /api/calendar | Get economic calendar within a selected period
*CandlesApi* | [**basic_candles**](docs/CandlesApi.md#basic_candles) | **GET** /api/bcandles | Get candlestick data
*CandlesApi* | [**enterprise_candles**](docs/CandlesApi.md#enterprise_candles) | **GET** /api/ecandles | Get candlestick data
*CandlesApi* | [**mega_candles**](docs/CandlesApi.md#mega_candles) | **GET** /api/mcandles | Get candlestick data
*CandlesApi* | [**pro_candles**](docs/CandlesApi.md#pro_candles) | **GET** /api/pcandles | Get candlestick data
*CandlesApi* | [**ultra_candles**](docs/CandlesApi.md#ultra_candles) | **GET** /api/ucandles | Get candlestick data
*GeneralApi* | [**info**](docs/GeneralApi.md#info) | **GET** /api/info | Get your package information as well as your limitations
*GeneralApi* | [**metadata**](docs/GeneralApi.md#metadata) | **GET** /api/metadata | Get metadata of selected timeframe/symbol pair
*GeneralApi* | [**search**](docs/GeneralApi.md#search) | **GET** /api/search | Search through the list of symbols to use correct one in the query


## Documentation For Models

 - [CalendarEvent](docs/CalendarEvent.md)
 - [Candle](docs/Candle.md)
 - [Info](docs/Info.md)
 - [Metadata](docs/Metadata.md)
 - [SearchResult](docs/SearchResult.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="rapidapiKey"></a>
### rapidapiKey

- **Type**: API key
- **API key parameter name**: X-RapidAPI-Key
- **Location**: HTTP header


## Author




